# IBATSCommon

[![Build Status](https://travis-ci.org/IBATS/IBATSCommon.svg?branch=master)](https://travis-ci.org/IBATS/IBATSCommon)
[![GitHub issues](https://img.shields.io/github/issues/IBATS/IBATSCommon.svg)](https://github.com/IBATS/IBATSCommon/issues)
[![GitHub forks](https://img.shields.io/github/forks/IBATS/IBATSCommon.svg)](https://github.com/IBATS/IBATSCommon/network)
[![GitHub stars](https://img.shields.io/github/stars/IBATS/IBATSCommon.svg)](https://github.com/IBATS/IBATSCommon/stargazers) 
[![GitHub license](https://img.shields.io/github/license/IBATS/IBATSCommon.svg)](https://github.com/IBATS/IBATSCommon/blob/master/LICENSE) 
[![HitCount](http://hits.dwyl.io/IBATS/https://github.com/DataIntegrationAlliance/IBATSCommon.svg)](http://hits.dwyl.io/DataIntegrationAlliance/https://github.com/IBATS/IBATSCommon)
[![Twitter](https://img.shields.io/twitter/url/https/github.com/IBATS/IBATSCommon.svg?style=social)](https://twitter.com/intent/tweet?text=Wow:&url=https%3A%2F%2Fgithub.com%2FIBATS%2FIBATSCommon) 

IBATS（Integration Backtest Analysis Trade System）的公共模块，所有Feeder, Trader均集成这个模块，并使用其提供的一些公共工具
